@@ -52,28 +52,6 @@ FUNCTION_ATTRIBUTE = 0x20
 FUNCTION_UNKNOWN_ANNOTATION = 0x40
 FUNCTION_THROW = 0x80
 
-"""
-These are currently unused. Should really handle these properly at some point.
-
-TYPE_MODIFIER_INLINE   = 0x010000
-TYPE_MODIFIER_EXTERN   = 0x020000
-TYPE_MODIFIER_STATIC   = 0x040000
-TYPE_MODIFIER_CONST    = 0x080000
-TYPE_MODIFIER_REGISTER = 0x100000
-TYPE_MODIFIER_VOLATILE = 0x200000
-TYPE_MODIFIER_MUTABLE  = 0x400000
-
-TYPE_MODIFIER_MAP = {
-    'inline': TYPE_MODIFIER_INLINE,
-    'extern': TYPE_MODIFIER_EXTERN,
-    'static': TYPE_MODIFIER_STATIC,
-    'const': TYPE_MODIFIER_CONST,
-    'register': TYPE_MODIFIER_REGISTER,
-    'volatile': TYPE_MODIFIER_VOLATILE,
-    'mutable': TYPE_MODIFIER_MUTABLE,
-    }
-"""
-
 _INTERNAL_TOKEN = 'internal'
 _NAMESPACE_POP = 'ns-pop'
 
@@ -236,9 +214,9 @@ class _GenericDeclaration(Node):
 # TODO(nnorwitz): merge with Parameter in some way?
 class VariableDeclaration(_GenericDeclaration):
 
-    def __init__(self, start, end, name, type, initial_value, namespace):
+    def __init__(self, start, end, name, var_type, initial_value, namespace):
         _GenericDeclaration.__init__(self, start, end, name, namespace)
-        self.type = type
+        self.type = var_type
         self.initial_value = initial_value
 
     def requires(self, node):
@@ -366,7 +344,10 @@ class Function(_GenericDeclaration):
         return self.body is not None
 
     def is_exportable(self):
-        if self.return_type and 'static' in self.return_type.modifiers:
+        if (
+            (self.return_type and 'static' in self.return_type.modifiers) or
+            self.templated_types
+        ):
             return False
         return None not in self.namespace
 
@@ -658,8 +639,10 @@ class TypeConverter(object):
             return None
         start = return_type_seq[0].start
         end = return_type_seq[-1].end
-        _, name, templated_types, modifiers, default, other_tokens = \
-            self.declaration_to_parts(return_type_seq, False)
+
+        _, name, templated_types, modifiers, __, other_tokens = (
+            self.declaration_to_parts(return_type_seq, False))
+
         names = [n.name for n in other_tokens]
         reference = '&' in names
         pointer = '*' in names
@@ -681,7 +664,10 @@ class TypeConverter(object):
 class AstBuilder(object):
 
     def __init__(self, token_stream, filename, in_class='', visibility=None,
-                 namespace_stack=[]):
+                 namespace_stack=None):
+        if namespace_stack is None:
+            namespace_stack = []
+
         self.tokens = token_stream
         self.filename = filename
         # TODO(nnorwitz): use a better data structure (deque) for the queue.
@@ -695,7 +681,6 @@ class AstBuilder(object):
         else:
             self.in_class_name_only = in_class.split('::')[-1]
         self.visibility = visibility
-        self.in_function = False
         self.current_token = None
         # Keep the state whether we are currently handling a typedef or not.
         self._handling_typedef = False
@@ -731,7 +716,10 @@ class AstBuilder(object):
                 raise
 
     def _create_variable(self, pos_token, name, type_name, type_modifiers,
-                         ref_pointer_name_seq, templated_types=[], value=''):
+                         ref_pointer_name_seq, templated_types=None, value=''):
+        if templated_types is None:
+            templated_types = []
+
         reference = '&' in ref_pointer_name_seq
         pointer = '*' in ref_pointer_name_seq
         array = '[' in ref_pointer_name_seq
@@ -751,9 +739,12 @@ class AstBuilder(object):
                 # The token name is the same as the class, must be a ctor if
                 # there is a paren. Otherwise, it's the return type.
                 # Peek ahead to get the next token to figure out which.
-                next = self._get_next_token()
-                self._add_back_token(next)
-                if next.token_type == tokenize.SYNTAX and next.name == '(':
+                next_item = self._get_next_token()
+                self._add_back_token(next_item)
+                if (
+                    next_item.token_type == tokenize.SYNTAX and
+                    next_item.name == '('
+                ):
                     return self._get_method([token], FUNCTION_CTOR, None, True)
                 # Fall through--handle like any other method.
 
@@ -887,13 +878,13 @@ class AstBuilder(object):
             elif name.startswith('if'):
                 count += 1
 
-    def _get_matching_char(self, open_paren, close_paren, GetNextToken=None):
-        if GetNextToken is None:
-            GetNextToken = self._get_next_token
+    def _get_matching_char(self, open_paren, close_paren, get_next_token=None):
+        if get_next_token is None:
+            get_next_token = self._get_next_token
         # Assumes the current token is open_paren and we will consume
         # and return up to the close_paren.
         count = 1
-        token = GetNextToken()
+        token = get_next_token()
         while True:
             if token.token_type == tokenize.SYNTAX:
                 if token.name == open_paren:
@@ -903,7 +894,7 @@ class AstBuilder(object):
                     if count == 0:
                         break
             yield token
-            token = GetNextToken()
+            token = get_next_token()
         yield token
 
     def _get_parameters(self):
@@ -937,11 +928,11 @@ class AstBuilder(object):
 
     def get_name(self, seq=None):
         """Returns ([tokens], next_token_info)."""
-        GetNextToken = self._get_next_token
+        get_next_token = self._get_next_token
         if seq is not None:
             it = iter(seq)
-            GetNextToken = lambda: next(it)
-        next_token = GetNextToken()
+            get_next_token = lambda: next(it)
+        next_token = get_next_token()
         tokens = []
         last_token_was_name = False
         while (next_token.token_type == tokenize.NAME or
@@ -955,9 +946,9 @@ class AstBuilder(object):
             tokens.append(next_token)
             # Handle templated names.
             if next_token.name == '<':
-                tokens.extend(self._get_matching_char('<', '>', GetNextToken))
+                tokens.extend(self._get_matching_char('<', '>', get_next_token))
                 last_token_was_name = True
-            next_token = GetNextToken()
+            next_token = get_next_token()
         return tokens, next_token
 
     def get_method(self, modifiers, templated_types):
@@ -1144,11 +1135,11 @@ class AstBuilder(object):
         names = []
         while i < end:
             # Iterate through the sequence parsing out each name.
-            new_name, next = self.get_name(seq_copy[i:])
-            assert new_name, 'Got empty new_name, next=%s' % next
+            new_name, next_item = self.get_name(seq_copy[i:])
+            assert new_name, 'Got empty new_name, next=%s' % next_item
             # We got a pointer or ref. Add it to the name.
-            if next and next.token_type == tokenize.SYNTAX:
-                new_name.append(next)
+            if next_item and next_item.token_type == tokenize.SYNTAX:
+                new_name.append(next_item)
             names.append(new_name)
             i += len(new_name)
 
@@ -1215,15 +1206,15 @@ class AstBuilder(object):
         fields = list(self._get_matching_char('{', '}'))
         del fields[-1]                  # Remove trailing '}'.
         if token.token_type == tokenize.SYNTAX and token.name == '{':
-            next = self._get_next_token()
+            next_item = self._get_next_token()
             new_type = ctor(token.start, token.end, name, fields,
                             self.namespace_stack)
             # A name means this is an anonymous type and the name
             # is the variable declaration.
-            if next.token_type != tokenize.NAME:
+            if next_item.token_type != tokenize.NAME:
                 return new_type
             name = new_type
-            token = next
+            token = next_item
 
         # Must be variable declaration using the type prefixed with keyword.
         assert token.token_type == tokenize.NAME, token
