@@ -67,12 +67,12 @@ class Module(object):
 
 
 def _is_header_file(filename):
-    base, ext = os.path.splitext(filename)
+    _, ext = os.path.splitext(filename)
     return ext.lower() in ('.h', '.hpp', '.h++', '.hxx')
 
 
 def _is_cpp_file(filename):
-    base, ext = os.path.splitext(filename)
+    _, ext = os.path.splitext(filename)
     return ext.lower() in ('.c', '.cc', '.cpp', '.c++', '.cxx')
 
 
@@ -372,9 +372,9 @@ class WarningHunter(object):
         #   * missing include for classes used for inheritenace
 
     def _find_public_function_warnings(self, node, name, primary_header,
-                                       public_symbols, all_headers):
+                                       all_headers):
         # Not found in the primary header, search all other headers.
-        for header_node, header in all_headers.values():
+        for _, header in all_headers.values():
             if name in header.public_symbols:
                 # If the primary.filename == header.filename, it probably
                 # indicates an error elsewhere. It sucks to mask it,
@@ -431,7 +431,6 @@ class WarningHunter(object):
                 self._find_public_function_warnings(node,
                                                     name,
                                                     primary_header,
-                                                    public_symbols,
                                                     all_headers)
 
         for name, declared_only in declared_only_symbols.items():
@@ -461,7 +460,7 @@ class WarningHunter(object):
             # be configurable or removed in the future. But it's easy
             # to check for now.
             msg = 'forward declarations not expected in source file'
-            self._add_warning(msg, next(forward_declarations.values()))
+            self._add_warning(msg, list(forward_declarations.values())[0])
 
         # A primary header is optional. However, when looking up
         # defined methods in the source, always look in the
@@ -483,8 +482,8 @@ class WarningHunter(object):
         #   * primitive member variables not initialized in ctor
 
 
-def get_line_number(metrics, node):
-    return metrics.get_line_number(node.start)
+def get_line_number(metrics_instance, node):
+    return metrics_instance.get_line_number(node.start)
 
 
 def run(filename, source, entire_ast, include_paths):
