@@ -80,7 +80,7 @@ class Token(object):
     __repr__ = __str__
 
 
-def _get_string(source, start, i):
+def _get_string(source, i):
     i = source.find('"', i + 1)
     while source[i - 1] == '\\':
         # Count the trailing backslashes.
@@ -120,6 +120,9 @@ def get_tokens(source):
       Token that represents the next token in the source.
 
     """
+    if not source.endswith('\n'):
+        source += '\n'
+
     # Cache various valid character sets for speed.
     valid_identifier_chars = VALID_IDENTIFIER_CHARS
     hex_digits = HEX_DIGITS
@@ -155,7 +158,7 @@ def get_tokens(source):
                 i = _get_char(source, start, i)
             elif source[i] == "'" and source[start:i] in _STR_PREFIXES:
                 token_type = CONSTANT
-                i = _get_string(source, start, i)
+                i = _get_string(source, i)
         elif c == '/' and source[i + 1] == '/':    # Find // comments.
             i = source.find('\n', i)
             if i == -1:  # Handle EOF.
@@ -164,7 +167,7 @@ def get_tokens(source):
         elif c == '/' and source[i + 1] == '*':    # Find /* comments. */
             i = source.find('*/', i) + 2
             continue
-        elif c in ':+-<>&|*=':                   # : or :: (plus other chars).
+        elif c in ':+-<>&!|*=':                   # : or :: (plus other chars).
             token_type = SYNTAX
             i += 1
             new_ch = source[i]
@@ -174,7 +177,7 @@ def get_tokens(source):
                 i += 1
             elif new_ch == '=':
                 i += 1
-        elif c in '()[]{}~!?^%;/.,':             # Handle single char tokens.
+        elif c in '()[]{}~?^%;/.,':             # Handle single char tokens.
             token_type = SYNTAX
             i += 1
             if c == '.' and source[i].isdigit():
@@ -205,7 +208,7 @@ def get_tokens(source):
                     break
         elif c == '"':                           # Find string.
             token_type = CONSTANT
-            i = _get_string(source, start, i)
+            i = _get_string(source, i)
         elif c == "'":                           # Find char.
             token_type = CONSTANT
             i = _get_char(source, start, i)
